@@ -98,6 +98,17 @@ class DataMetaclass(type):
                 setattr(result, key, deepcopy(val))
 
             return result
+        
+        def __getstate__(self):
+            from .parser import asdict
+            return asdict(self)
+        
+        def __setstate__(self, state: Dict[str, Any]):
+            from .parser import asclass
+            new = asclass(self.__class__, state)
+            for key in get_fields_info(self.__class__):
+                val = getattr(new, key)
+                setattr(self, key, val)
 
         def __iter__(self):
             for key in get_fields_info(self.__class__):
@@ -121,6 +132,8 @@ class DataMetaclass(type):
         data["__init__"] = __init__
         data["__copy__"] = __copy__
         data["__deepcopy__"] = __deepcopy__
+        data["__getstate__"] = __getstate__
+        data["__setstate__"] = __setstate__
         data["__iter__"] = __iter__
         data["__repr__"] = __repr__
 
