@@ -153,6 +153,9 @@ class Parser(metaclass=ParserMetaclass):
 
 class DictParser(Parser):
     def __call__(self, val: Any, field: Field):
+        if val == Ellipsis:
+            return val
+        
         if isinstance(field.annotation, get_args(Generic)):
             if getattr(field.annotation, "_name", None) == "Dict":
                 return parse(field.annotation, val)
@@ -204,7 +207,8 @@ def asdict(obj: Dataclass, by_alias: bool = True, parser: Parser = DictParser())
         val = parser(val, field)
 
         key = field.alias if by_alias and field.alias is not None else key
-        dictionary[key] = val
+        if val != Ellipsis:
+            dictionary[key] = val
 
     return dictionary
 
